@@ -20,8 +20,8 @@ class TemplateXML:
         xpath = self.get_xpath(key)
         self.set_value_xpath(xpath, value)
 
-    def set_body_from_file(self, path):
-        with open(path, 'r') as file:
+    def set_body_from_file(self, path, encoding="UTF-8"):
+        with open(path, 'r', encoding=encoding) as file:
             self._body = et.fromstring(file.read().encode())
 
     @staticmethod
